import { Project } from "@models/Project";
import { encryptClearField } from "@utils/decryption";
import { Types } from "mongoose";

export const createProject = async (name: string, userId?: string) => {
    const count = await Project.countDocuments({ creatorId: encryptClearField(userId || "") });
    if (count > 5) return { code: 95, message: "You have exceeded the project limit" };

    await Project.create({ name, creatorId: userId });
};

export const deleteProject = async (id: string) => {
    if (!Types.ObjectId.isValid(id))
        return { code: 3, message: "Invalid object id provided" };

    const project = await Project.findById(id);
    if (project === null) return { code: 5009, message: "The provided project id does not exist" };

    // TODO: Delete all licenses, groups, permissions, ..

    await project.delete();
};